--
-- Name: SetShuttleEnabledEvent
-- Description: Set shuttle enabled event for the Steerable specialization
-- Version: 2.0
-- Author: Templaer
-- Date: 10/04/2011
--

SetShuttleEnabledEvent = {};
SetShuttleEnabledEvent_mt = Class(SetShuttleEnabledEvent, Event);

InitEventClass(SetShuttleEnabledEvent, "SetShuttleEnabledEvent");

function SetShuttleEnabledEvent:emptyNew()
	local self = Event:new(SetShuttleEnabledEvent_mt);
	self.className="SetShuttleEnabledEvent";
	return self;
end;

function SetShuttleEnabledEvent:new(object, shuttleEnabled)
	local self = SetShuttleEnabledEvent:emptyNew()
	self.object = object;
	self.shuttleEnabled = shuttleEnabled;
	return self;
end;

function SetShuttleEnabledEvent:readStream(streamId, connection)
	local id = streamReadInt32(streamId);
	self.shuttleEnabled = streamReadBool(streamId);
	self.object = networkGetObject(id);
	self:run(connection);
end;

function SetShuttleEnabledEvent:writeStream(streamId, connection)
	streamWriteInt32(streamId, networkGetObjectId(self.object));
	streamWriteBool(streamId, self.shuttleEnabled);
end;

function SetShuttleEnabledEvent:run(connection)
	self.object:setShuttleEnabled(self.shuttleEnabled, true);
	if not connection:getIsServer() then
		g_server:broadcastEvent(SetShuttleEnabledEvent:new(self.object, self.shuttleEnabled), nil, connection, self.object);
	end;
end;

function SetShuttleEnabledEvent.sendEvent(vehicle, shuttleEnabled, noEventSend)
	if shuttleEnabled ~= vehicle.shuttleEnabled then
		if noEventSend == nil or noEventSend == false then
			if g_server ~= nil then
				g_server:broadcastEvent(SetShuttleEnabledEvent:new(vehicle, shuttleEnabled), nil, nil, vehicle);
			else
				g_client:getServerConnection():sendEvent(SetShuttleEnabledEvent:new(vehicle, shuttleEnabled));
			end;
		end;
	end;
end;